@@ -406,7 +406,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (noise_min, noise_max)
 
     def statusNoise2(self, channel_index: int, offset: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
-        """Retrieve the acquired data samples from the specified AnalogIn instrument channel.
+        """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
             channel_index (int): The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -463,7 +463,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return num_bits
 
     def recordLengthSet(self, record_duration: float) -> None:
-        """Set the record length, in seconds.
+        """Set the |AnalogIn| record length, in seconds.
 
         Note:
             This value is only used when the acquisition mode is configured as
@@ -482,7 +482,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def recordLengthGet(self) -> float:
-        """Get the record length, in seconds.
+        """Get the |AnalogIn| record length, in seconds.
 
         Note:
             This value is only used when the acquisition mode is configured as
@@ -504,7 +504,8 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return record_duration
 
     def frequencyInfo(self) -> Tuple[float, float]:
-        """Retrieve the minimum and maximum configurable ADC sample frequency, in samples/second.
+        """Retrieve the minimum and maximum configurable ADC sample frequency of the |AnalogIn| instrument,
+        in samples/second.
 
         Returns:
             Tuple[float, float]: The allowed sample frequency range (min, max), in samples/second.
@@ -554,7 +555,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return sample_frequency
 
     def bufferSizeInfo(self) -> Tuple[int, int]:
-        """Returns the minimum and maximum allowable buffer size for the instrument, in samples.
+        """Returns the minimum and maximum allowable buffer size for the |AnalogIn| instrument, in samples.
 
         When using the :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode,
         the buffer size should be left at the default value, which is equal to the maximum value.
@@ -731,7 +732,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def channelCount(self) -> int:
-        """Read the number of analog input channels.
+        """Read the number of |AnalogIn| input channels.
 
         Returns:
             int: The number of analog input channels.
@@ -753,7 +754,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def channelEnableSet(self, channel_index: int, enable: bool) -> None:
-        """Enable or disable the specified analog input channel.
+        """Enable or disable the specified |AnalogIn| input channel.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -767,7 +768,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelEnableGet(self, channel_index: int) -> bool:
-        """Get the current enable/disable status of the specified |AnalogIn| channel.
+        """Get the current enable/disable status of the specified |AnalogIn| input channel.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -786,10 +787,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return enable
 
     def channelFilterInfo(self) -> List[DwfAnalogInFilter]:
-        """Get a list of supported channel filter settings.
+        """Get a list of valid |AnalogIn| channel filter settings.
 
         Returns:
-            List[DwfAnalogInFilter]: A list of possible channel filter settings.
+            List[DwfAnalogInFilter]: A list of valid channel filter settings.
 
         Raises:
             DwfLibraryError: An error occurred while getting the channel filter info.
@@ -804,7 +805,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_filter_list
 
     def channelFilterSet(self, channel_index: int, channel_filter: DwfAnalogInFilter) -> None:
-        """Set the filter for a specified channel.
+        """Set the filter for a specified |AnalogIn| input channel.
 
         Parameters:
             channel_index (int): The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -818,7 +819,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelFilterGet(self, channel_index: int) -> DwfAnalogInFilter:
-        """Get the channel filter setting.
+        """Get the |AnalogIn| input channel filter setting.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -837,7 +838,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_filter
 
     def channelRangeInfo(self) -> Tuple[float, float, int]:
-        """Report the possible voltage ranges of the analog input channels, in Volts.
+        """Report the possible voltage ranges of the |AnalogIn| input channels, in Volts.
 
         The values returned represent ideal values.
         The actual calibrated ranges are channel-dependent.
@@ -872,11 +873,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (channel_range_min, channel_range_max, channel_range_num_steps)
 
     def channelRangeSet(self, channel_index: int, channel_range: float) -> None:
-        """Set the range setting of the specified channel, in Volts.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            channel_range: float: The requested channel range, in Volts.
+        """Set the range setting of the specified |AnalogIn| input channel, in Volts.
 
         Note:
             The actual range set will generally be different from the requested range.
@@ -884,6 +881,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Note:
             Changing the channel range may also change the channel offset.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+            channel_range: float: The requested channel range, in Volts.
+
         Raises:
             DwfLibraryError: An error occurred while setting the channel voltage range.
         """
@@ -892,7 +893,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelRangeGet(self, channel_index: int) -> float:
-        """Get the range setting of the specified channel, in Volts.
+        """Get the range setting of the specified |AnalogIn| input channel, in Volts.
 
         Together with the channel offset, this value can be used to transform raw binary ADC values into Volts.
 
@@ -913,7 +914,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_range
 
     def channelRangeSteps(self) -> List[float]:
-        """Report the possible voltage ranges of the analog input channels, in Volts, as a list.
+        """Report the possible voltage ranges of the |AnalogIn| input channels, in Volts, as a list.
 
         The values returned represent ideal values.
         The actual calibrated ranges are channel-dependent.
@@ -939,7 +940,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_range_array
 
     def channelOffsetInfo(self) -> Tuple[float, float, int]:
-        """Get the possible channel offset settings, in Volts.
+        """Get the possible |AnalogIn| input channel offset settings, in Volts.
 
         Returns:
             Tuple[float, float, int]: The minimum channel offset (Volts), maximum channel offset (Volts),
@@ -962,11 +963,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (offset_min, offset_max, offset_num_steps)
 
     def channelOffsetSet(self, channel_index: int, channel_offset: float) -> None:
-        """Set the channel offset, in Volts.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            channel_offset: float: The channel offset, in Volts.
+        """Set the |AnalogIn| input channel offset, in Volts.
 
         Note:
             The actual offset will generally be different from the requested offset.
@@ -974,6 +971,10 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Note:
             Changing the channel offset may also change the channel range.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+            channel_offset: float: The channel offset, in Volts.
+
         Raises:
             DwfLibraryError: An error occurred while setting the channel offset.
         """
@@ -982,7 +983,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelOffsetGet(self, channel_index: int) -> float:
-        """Get the channel offset, in Volts.
+        """Get the |AnalogIn| input channel offset, in Volts.
 
         Together with the channel range, this value can be used to transform raw binary ADC values into Volts.
 
@@ -1003,7 +1004,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_offset
 
     def channelAttenuationSet(self, channel_index: int, channel_attenuation: float) -> None:
-        """Set the channel attenuation setting.
+        """Set the |AnalogIn| input channel attenuation setting.
 
         The channel attenuation is a dimensionless factor.
 
@@ -1031,7 +1032,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelAttenuationGet(self, channel_index: int) -> float:
-        """Get the channel attenuation setting.
+        """Get the |AnalogIn| input channel attenuation setting.
 
         The channel attenuation is a dimensionless factor.
 
@@ -1060,16 +1061,16 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_attenuation
 
     def channelBandwidthSet(self, channel_index: int, channel_bandwidth: float) -> None:
-        """Set the channel bandwidth setting.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            channel_bandwidth: float: The channel bandwidth setting, in Hz.
+        """Set the |AnalogIn| input channel bandwidth setting.
 
         Note:
             On the Analog Discovery 2, the channel bandwidth setting exists and can be set and retrieved,
             but the value has no effect.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+            channel_bandwidth: float: The channel bandwidth setting, in Hz.
+
         Raises:
             DwfLibraryError: An error occurred while setting the channel bandwidth.
         """
@@ -1078,15 +1079,15 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelBandwidthGet(self, channel_index: int) -> float:
-        """Get the channel bandwidth setting.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+        """Get the |AnalogIn| input channel bandwidth setting.
 
         Note:
             On the Analog Discovery 2, the channel bandwidth setting exists and can be set and retrieved,
             but the value has no effect.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+
         Returns:
             float: The channel bandwidth setting, in Hz.
 
@@ -1101,16 +1102,16 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return channel_bandwidth
 
     def channelImpedanceSet(self, channel_index: int, channel_impedance: float) -> None:
-        """Set the channel impedance setting, in Ohms.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            channel_impedance: float: channel impedance setting, in Ohms.
+        """Set the |AnalogIn| input channel impedance setting, in Ohms.
 
         Note:
             On the Analog Discovery 2, the channel impedance setting exists and can be set and retrieved,
             but the value has no effect.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+            channel_impedance: float: channel impedance setting, in Ohms.
+
         Raises:
             DwfLibraryError: An error occurred while setting the current channel impedance.
         """
@@ -1119,15 +1120,15 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelImpedanceGet(self, channel_index: int) -> float:
-        """Get the channel impedance setting, in Ohms.
-
-        Parameters:
-            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+        """Get the |AnalogIn| input channel impedance setting, in Ohms.
 
         Note:
             On the Analog Discovery 2, the channel impedance setting exists and can be set and retrieved,
             but the value has no effect.
 
+        Parameters:
+            channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
+
         Returns:
             float: The channel impedance setting, in Ohms.
 
@@ -1344,9 +1345,9 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerForce(self) -> None:
-        """Force assertion of the instrument trigger.
+        """Force assertion of the |AnalogIn| instrument trigger.
 
-        Note:
+        Important:
             This method forces the |AnalogIn| device to act as if it was triggered, independent of the currently
             active trigger source. It does not generate an artificial trigger event on the |AnalogIn| trigger detector.
 
@@ -1364,7 +1365,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
-        """Get |AnalogIn| trigger detector holdoff info.
+        """Get |AnalogIn| trigger detector holdoff info, in seconds.
 
         The trigger holdoff setting is the minimum time (in seconds) for a trigger to be
         recognized after a previous trigger.
@@ -1397,7 +1398,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_holdoff_min, trigger_holdoff_max, trigger_holdoff_num_steps)
 
     def triggerHoldOffSet(self, trigger_holdoff: float) -> None:
-        """Set |AnalogIn| trigger detector  holdoff value.
+        """Set the |AnalogIn| trigger detector  holdoff value, in seconds.
 
         Parameters:
             trigger_holdoff (float): The holdoff setting, in seconds.
@@ -1410,7 +1411,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerHoldOffGet(self) -> float:
-        """Get current |AnalogIn| trigger detector holdoff value.
+        """Get the current |AnalogIn| trigger detector holdoff value, in seconds.
 
         Returns:
             float: The currently configured trigger holdoff value, in seconds.
@@ -1498,7 +1499,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_channel_index_min, trigger_channel_index_max)
 
     def triggerChannelSet(self, trigger_channel_index: int) -> None:
-        """Set |AnalogIn| trigger detector channel.
+        """Set the |AnalogIn| trigger detector channel.
 
         This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
 
@@ -1513,12 +1514,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerChannelGet(self) -> int:
-        """Get |AnalogIn| trigger detector channel.
+        """Get the |AnalogIn| trigger detector channel.
 
         This is the analog input channel that the |AnalogIn| trigger detector is sensitive to.
 
         Returns:
-            int: The currently configured trigger channel.
+            int: The currently configured trigger detector channel.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger channel.
@@ -1549,7 +1550,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_filter_list
 
     def triggerFilterSet(self, trigger_filter: DwfAnalogInFilter) -> None:
-        """Set |AnalogIn| trigger detector filter.
+        """Set the |AnalogIn| trigger detector filter.
 
         Parameters:
             trigger_filter (DwfAnalogInFilter): The trigger filter to be selected.
@@ -1562,7 +1563,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerFilterGet(self) -> DwfAnalogInFilter:
-        """Get |AnalogIn| trigger detector filter.
+        """Get the |AnalogIn| trigger detector filter.
 
         Returns:
             DwfAnalogInFilter: The currently configured trigger filter.
@@ -1578,7 +1579,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_filter
 
     def triggerLevelInfo(self) -> Tuple[float, float, int]:
-        """Get |AnalogIn| trigger detector level info, in Volts.
+        """Get the |AnalogIn| trigger detector level info, in Volts.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger level values that can be configured.
@@ -1608,7 +1609,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_level_min, trigger_level_max, trigger_level_num_steps)
 
     def triggerLevelSet(self, trigger_level: float) -> None:
-        """Set |AnalogIn| trigger detector level, in Volts.
+        """Set the |AnalogIn| trigger detector level, in Volts.
 
         Parameters:
             trigger_level (float): The trigger level to be configured, in Volts.
@@ -1621,7 +1622,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerLevelGet(self) -> float:
-        """Get |AnalogIn| trigger detector level, in Volts.
+        """Get the |AnalogIn| trigger detector level, in Volts.
 
         Returns:
             float: The currently configured trigger level, in Volts.
@@ -1667,7 +1668,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_hysteresis_min, trigger_hysteresis_max, trigger_hysteresis_num_steps)
 
     def triggerHysteresisSet(self, trigger_hysteresis: float) -> None:
-        """Set |AnalogIn| trigger detector hysteresis, in Volts.
+        """Set the |AnalogIn| trigger detector hysteresis, in Volts.
 
         Parameters:
             trigger_hysteresis (float): The trigger hysteresis to be configured, in Volts.
@@ -1680,7 +1681,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerHysteresisGet(self) -> float:
-        """Get |AnalogIn| trigger detector trigger hysteresis, in Volts.
+        """Get the |AnalogIn| trigger detector trigger hysteresis, in Volts.
 
         Returns:
             float: The currently configured trigger hysteresis, in Volts.
@@ -1716,7 +1717,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return trigger_condition_list
 
     def triggerConditionSet(self, trigger_condition: DwfTriggerSlope) -> None:
-        """Set |AnalogIn| trigger detector condition.
+        """Set the |AnalogIn| trigger detector condition.
 
         Parameters:
             trigger_condition (DwfTriggerSlope): The trigger condition to be configured.
@@ -1729,7 +1730,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerConditionGet(self) -> DwfTriggerSlope:
-        """Get |AnalogIn| trigger detector condition.
+        """Get the |AnalogIn| trigger detector condition.
 
         Returns:
             DwfTriggerSlope: The currently configured trigger condition.
@@ -1775,7 +1776,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return (trigger_length_min, trigger_length_max, trigger_length_num_steps)
 
     def triggerLengthSet(self, trigger_length: float) -> None:
-        """Set |AnalogIn| trigger detector length, in seconds.
+        """Set the |AnalogIn| trigger detector length, in seconds.
 
         Parameters:
             trigger_length (float): The trigger length to be configured, in seconds.
@@ -1788,7 +1789,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerLengthGet(self) -> float:
-        """Get |AnalogIn| trigger detector length, in seconds.
+        """Get the |AnalogIn| trigger detector length, in seconds.
 
         Returns:
             float: The currently configured trigger length, in seconds.
@@ -1821,7 +1822,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return tlc_list
 
     def triggerLengthConditionSet(self, trigger_length_condition: DwfAnalogInTriggerLengthCondition) -> None:
-        """Set |AnalogIn| trigger detector length condition.
+        """Set the |AnalogIn| trigger detector length condition.
 
         Parameters:
             trigger_length_condition (DwfAnalogInTriggerLengthCondition):
@@ -1837,7 +1838,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerLengthConditionGet(self) -> DwfAnalogInTriggerLengthCondition:
-        """Get |AnalogIn| trigger detector length condition.
+        """Get the |AnalogIn| trigger detector length condition.
 
         Returns:
             DwfAnalogInTriggerLengthCondition: The currently configured trigger length condition.
@@ -1861,7 +1862,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def samplingSourceSet(self, sampling_source: DwfTriggerSource) -> None:
-        """Set |AnalogIn| sampling source.
+        """Set the |AnalogIn| sampling source.
 
         Parameters:
             sampling_source (DwfTriggerSource): The sampling source to be configured.
@@ -1874,7 +1875,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def samplingSourceGet(self) -> DwfTriggerSource:
-        """Get |AnalogIn| sampling source.
+        """Get the |AnalogIn| sampling source.
 
         Returns:
             DwfTriggerSource: The currently configured sampling source.
@@ -1890,7 +1891,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return sampling_source
 
     def samplingSlopeSet(self, sampling_slope: DwfTriggerSlope) -> None:
-        """Set |AnalogIn| sampling slope.
+        """Set the |AnalogIn| sampling slope.
 
         Parameters:
             sampling_slope (DwfTriggerSlope): The sampling slope to be configured.
@@ -1903,7 +1904,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def samplingSlopeGet(self) -> DwfTriggerSlope:
-        """Get |AnalogIn| sampling slope.
+        """Get the |AnalogIn| sampling slope.
 
         Returns:
             DwfTriggerSlope: The currently configured sampling slope.
@@ -1919,7 +1920,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         return sampling_slope
 
     def samplingDelaySet(self, sampling_delay: float) -> None:
-        """Set |AnalogIn| sampling delay.
+        """Set the |AnalogIn| sampling delay, in seconds.
 
         Parameters:
             sampling_delay (float): The sampling delay to be configured, in seconds.
@@ -1932,7 +1933,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def samplingDelayGet(self) -> float:
-        """Get |AnalogIn| sampling delay.
+        """Get the |AnalogIn| sampling delay, in seconds.
 
         Returns:
             float: The currently configured sampling delay, in seconds.
