@@ -49,9 +49,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The output channel to configure. Specify -1 to configure all channels.
             start (int): Whether to start/stop the instrument:
 
-               * 0: Stop instrument.
-               * 1: Start instrument.
-               * 3: Apply settings; do not change instrument state.
+               * 0 — Stop instrument
+               * 1 — Start instrument
+               * 3 — Apply settings; do not change instrument state
 
         Raises:
             DwfLibraryError: An error occurred while executing the *configure* operation.
@@ -61,7 +61,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def status(self, channel_index: int) -> DwfState:
-        """Get |AnalogOut| instrument channel state.
+        """Get the |AnalogOut| instrument channel state.
 
         Executing this method initiates a status request to the |AnalogOut| instrument and receives its response.
 
@@ -110,13 +110,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def waitInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get wait info.
+        """Get the |AnalogOut| channel valid |Wait:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of configurable wait durations.
+            Tuple[float, float]: The range of configurable |Wait:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -131,11 +131,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (secMin, secMax)
 
     def waitSet(self, channel_index: int, wait_duration: float) -> None:
-        """Set wait state duration, in seconds.
+        """Set the |AnalogOut| channel |Wait:link| state duration, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            wait_duration (float): The wait duration, in seconds.
+            wait_duration (float): The |Wait:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -145,13 +145,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def waitGet(self, channel_index: int) -> float:
-        """Get wait state duration in seconds.
+        """Get the |AnalogOut| channel |Wait:link| state duration, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            float: The currently configured wait duration.
+            float: The currently configured |Wait:link| state duration.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -164,13 +164,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return wait_duration
 
     def runInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get run duration range, in seconds.
+        """Get the |AnalogOut| channel valid |Running:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of allowed run-time, in seconds.
+            Tuple[float, float]: The range of allowed |Running:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -185,11 +185,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (secMin, secMax)
 
     def runSet(self, channel_index: int, run_duration: float) -> None:
-        """Set run duration, in seconds.
+        """Set the |AnalogOut| channel |Running:link| state duration, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            run_duration (float): The run duration, in seconds.
+            run_duration (float): The |Running:link| state duration, in seconds.
                 Specify 0 for a run of indefinite length.
 
         Raises:
@@ -200,13 +200,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def runGet(self, channel_index: int) -> float:
-        """Get run-time, in seconds.
+        """Get the |AnalogOut| channel |Running:link| state duration, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            float: The currently active run setting, in seconds.
+            float: The currently configured |Running:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -219,13 +219,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return run_duration
 
     def runStatus(self, channel_index: int) -> float:
-        """Get run status.
+        """Get |Running:link| state duration time left.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            float: The current run status, in seconds.
+            float: The current time remaining in the |Running:link| state, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -238,13 +238,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return secRun
 
     def repeatTriggerSet(self, channel_index: int, repeat_trigger_flag: bool) -> None:
-        """Set repeat trigger setting.
+        """Set the |AnalogOut| channel *repeat trigger* setting.
 
-        This setting determines if a new trigger must precede all runs, or only the first one.
+        This setting determines if a new trigger must precede all Wait/Running sequences, or only the first one.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            repeat_trigger_flag (bool): The trigger repeat flag.
+            repeat_trigger_flag (bool): True if each Wait/Running sequence needs its own trigger,
+                False if only the first Wait/Running sequence needs a trigger.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -254,13 +255,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def repeatTriggerGet(self, channel_index: int) -> bool:
-        """Get repeat trigger setting.
+        """Get the |AnalogOut| channel *repeat trigger* setting.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            bool: The currently configured repeat trigger setting.
+            bool: The currently configured *repeat trigger* setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -276,7 +277,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return repeat_trigger_flag
 
     def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get repeat info.
+        """Get |AnalogOut| repeat count range.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -297,7 +298,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (nMin, nMax)
 
     def repeatSet(self, channel_index: int, repeat: int) -> None:
-        """Set repeat setting.
+        """Set the |AnalogOut| repeat count setting.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -311,7 +312,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def repeatGet(self, channel_index: int) -> int:
-        """Get repeat setting.
+        """Get the |AnalogOut| repeat count setting.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -330,13 +331,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return repeat
 
     def repeatStatus(self, channel_index: int) -> int:
-        """Get repeat status.
+        """Get the |AnalogOut| current repeat count, which decreases to 0 while going through
+        Running/Wait state cycles.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            int: The current repeat value.
+            int: The current repeat count value.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -349,14 +351,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return repeat_status
 
     def masterSet(self, channel_index: int, master_channel_index: int) -> None:
-        """Set master status.
+        """Set the |AnalogOut| channel master.
 
-        Sets the state machine master of the channel generator.
+        Sets the state machine master channel f the analog output channel.
 
         Parameters:
             channel_index (int): The output channel for which to set the master setting.
                 Specify -1 to set all channels.
-            master_channel_index (int): The master channel index.
+            master_channel_index (int): The master channel.
 
         Raises:
             DwfLibraryError: An error occurred while setting the value.
@@ -366,10 +368,10 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def masterGet(self, channel_index: int) -> int:
-        """Get master status.
+        """Get the |AnalogOut| channel master.
 
         Parameters:
-            channel_index (int): The output channel for which to get the status.
+            channel_index (int): The analog output channel for which to get the status.
 
         Returns:
             int: The index of the master channel which the channel is configured to follow.
@@ -391,7 +393,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get analog out trigger source info.
+        """Get a list of valid |AnalogOut| instrument trigger sources.
 
         Warning:
             This method is obsolete. Use the generic |DwfDevice.triggerInfo:link| method instead.
@@ -412,7 +414,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return trigger_source_info_list
 
     def triggerSourceSet(self, channel_index: int, trigger_source: DwfTriggerSource) -> None:
-        """Set trigger source.
+        """Set the |AnalogOut| channel trigger source.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -429,7 +431,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self, channel_index: int) -> DwfTriggerSource:
-        """Get trigger source.
+        """Get the |AnalogOut| channel trigger source.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -448,7 +450,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerSlopeSet(self, channel_index: int, trigger_slope: DwfTriggerSlope) -> None:
-        """Set trigger slope.
+        """Set the |AnalogOut| channel trigger slope.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -465,7 +467,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self, channel_index: int) -> DwfTriggerSlope:
-        """Get trigger slope.
+        """Get the |AnalogOut| channel trigger slope.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -490,7 +492,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
-        """Set analog output mode.
+        """Set the |AnalogOut| channel mode (voltage or current).
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -504,7 +506,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def modeGet(self, channel_index: int) -> DwfAnalogOutMode:
-        """Get analog output mode.
+        """Get the |AnalogOut| channel mode (voltage or current).
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -523,7 +525,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return mode
 
     def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
-        """Get idle info.
+        """Get the valid |AnalogOut| channel idle settings.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -543,7 +545,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return idle_list
 
     def idleSet(self, channel_index: int, idle: DwfAnalogOutIdle) -> None:
-        """Set idle behavior.
+        """Set the |AnalogOut| channel idle behavior.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -557,7 +559,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def idleGet(self, channel_index: int) -> DwfAnalogOutIdle:
-        """Get idle behavior.
+        """Get the |AnalogOut| channel idle behavior.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -576,7 +578,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return idle
 
     def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get limitation info.
+        """Get the |AnalogOut| channel limitation range, in Volts or Amps.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -597,7 +599,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (limitation_min, limitation_max)
 
     def limitationSet(self, channel_index: int, limitation: float) -> None:
-        """Set limitation value.
+        """Set the |AnalogOut| channel limitation value, in Volts or Amps.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -611,7 +613,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def limitationGet(self, channel_index: int) -> float:
-        """Get limitation value (in Volts or Amps).
+        """Get the |AnalogOut| channel limitation value, in Volts or Amps.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -636,7 +638,10 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
-        """Set custom AM/FM enable status.
+        """Set the |AnalogOut| channel custom AM/FM enable status.
+
+        Todo:
+            Understand and document what this setting does.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -650,7 +655,10 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def customAMFMEnableGet(self, channel_index: int) -> bool:
-        """Get custom AM/FM enable status.
+        """Get the |AnalogOut| channel custom AM/FM enable status.
+
+        Todo:
+            Understand and document what this setting does.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -675,7 +683,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def nodeInfo(self, channel_index: int) -> List[DwfAnalogOutNode]:
-        """Get a list of valid node channel nodes.
+        """Get a list of valid |AnalogOut| channel nodes.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -701,7 +709,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def nodeEnableSet(self, channel_index: int, node: DwfAnalogOutNode, enable: bool) -> None:
-        """Enabled or disable a channel node.
+        """Enabled or disable an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -716,14 +724,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeEnableGet(self, channel_index: int, node: DwfAnalogOutNode) -> bool:
-        """"Get channel node enabled state.
+        """Get the enabled state of an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            bool: The enable setting.
+            bool: The currently configured enable setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -736,7 +744,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return enable
 
     def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> List[DwfAnalogOutFunction]:
-        """Get channel node waveform shape function info.
+        """Get the valid waveform shape function options of an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -761,7 +769,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return func_list
 
     def nodeFunctionSet(self, channel_index: int, node: DwfAnalogOutNode, func: DwfAnalogOutFunction) -> None:
-        """Set channel node waveform shape function.
+        """Set the waveform shape function for an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -776,7 +784,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeFunctionGet(self, channel_index: int, node: DwfAnalogOutNode) -> DwfAnalogOutFunction:
-        """Get channel node waveform shape function.
+        """Get the waveform shape function for an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -796,7 +804,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return func
 
     def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node frequency info, in Hz.
+        """Get the channel node frequency info for an |AnalogOut| channel node, in Hz.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -823,7 +831,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (frequency_min, frequency_max)
 
     def nodeFrequencySet(self, channel_index: int, node: DwfAnalogOutNode, frequency: float) -> None:
-        """Set channel node frequency, in Hz.
+        """Set the channel node frequency for an |AnalogOut| channel node, in Hz.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -842,7 +850,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeFrequencyGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get channel node frequency, in Hz.
+        """Get the frequency for an |AnalogOut| channel node, in Hz.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -866,7 +874,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return frequency
 
     def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node amplitude range, in Volts.
+        """Get the amplitude range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -893,7 +901,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (amplitude_min, amplitude_max)
 
     def nodeAmplitudeSet(self, channel_index: int, node: DwfAnalogOutNode, amplitude: float) -> None:
-        """Set channel node amplitude, in Volts.
+        """Set the amplitude for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -912,14 +920,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeAmplitudeGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get channel node amplitude, in Volts.
+        """Get the amplitude for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            float: The currently configured channel amplitude, in Volts.
+            float: The currently configured amplitude, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -936,7 +944,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return amplitude
 
     def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node valid offset range, in Volts.
+        """Get the valid offset range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -958,7 +966,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (offset_min, offset_max)
 
     def nodeOffsetSet(self, channel_index: int, node: DwfAnalogOutNode, offset: float) -> None:
-        """Set channel node offset, in Volts.
+        """Set the offset for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -973,7 +981,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeOffsetGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get channel node offset, in Volts.
+        """Get the offset for an |AnalogOut| channel node, in Volts.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -993,7 +1001,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return offset
 
     def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node symmetry info.
+        """Get the *symmetry* range for an |AnalogOut| channel node.
 
         The *symmetry* value alters the waveform shape function of the node.
 
@@ -1026,7 +1034,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (symmetry_min, symmetry_max)
 
     def nodeSymmetrySet(self, channel_index: int, node: DwfAnalogOutNode, symmetry: float) -> None:
-        """Set channel node symmetry value.
+        """Set the *symmetry* value for an |AnalogOut| channel node.
 
         The *symmetry* value alters the waveform shape function of the node.
 
@@ -1047,7 +1055,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodeSymmetryGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get channel node symmetry setting.
+        """Get the *symmetry* value for an |AnalogOut| channel node.
 
         The *symmetry* value alters the waveform shape function of the node.
 
@@ -1073,7 +1081,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return symmetry
 
     def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node phase range, in degrees.
+        """Get the valid phase range for an |AnalogOut| channel node, in degrees.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1100,7 +1108,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (phase_min, phase_max)
 
     def nodePhaseSet(self, channel_index: int, node: DwfAnalogOutNode, phase: float) -> None:
-        """Set channel node phase, in degrees.
+        """Set the phase for an |AnalogOut| channel node, in degrees.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1119,7 +1127,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodePhaseGet(self, channel_index: int, node: DwfAnalogOutNode) -> float:
-        """Get channel node phase, in degrees.
+        """Get the phase for an |AnalogOut| channel node, in degrees.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1149,7 +1157,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
-        """Get channel node data info, in samples.
+        """Get data info for an |AnalogOut| channel node, in samples.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1176,7 +1184,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (samples_min, samples_max)
 
     def nodeDataSet(self, channel_index: int, node: DwfAnalogOutNode, data: np.ndarray) -> None:
-        """Set channel node data.
+        """Set the data for an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1199,7 +1207,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[int, int, int]:
-        """Get channel node play status.
+        """Get the play status for an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1229,12 +1237,12 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (data_free, data_lost, data_corrupted)
 
     def nodePlayData(self, channel_index: int, node: DwfAnalogOutNode, data: np.ndarray) -> None:
-        """Configure channel node play data.
+        """Provide the playback data for an |AnalogOut| channel node.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
             node (DwfAnalogOutNode): The channel node.
-            data (np.ndarray): The data.
+            data (np.ndarray): The playback data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1294,7 +1302,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return enable
 
     def functionInfo(self, channel_index: int) -> List[DwfAnalogOutFunction]:
-        """Get |AnalogOut| channel waveform shape function info.
+        """Get the |AnalogOut| channel waveform shape function info.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFunctionInfo` method instead.
@@ -1318,7 +1326,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return function_info_list
 
     def functionSet(self, channel_index: int, func: DwfAnalogOutFunction) -> None:
-        """Set |AnalogOut| channel waveform shape function.
+        """Set the |AnalogOut| channel waveform shape function.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFunctionSet` method instead.
@@ -1335,7 +1343,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def functionGet(self, channel_index: int) -> DwfAnalogOutFunction:
-        """Get |AnalogOut| channel waveform shape function.
+        """Get the |AnalogOut| channel waveform shape function.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFunctionGet` method instead.
@@ -1357,7 +1365,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return func
 
     def frequencyInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get |AnalogOut| channel valid frequency range, in Hz.
+        """Get the |AnalogOut| channel valid frequency range, in Hz.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFrequencyInfo` method instead.
@@ -1381,7 +1389,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (hzMin, hzMax)
 
     def frequencySet(self, channel_index: int, frequency: float) -> None:
-        """Set |AnalogOut| channel frequency, in Hz.
+        """Set the |AnalogOut| channel frequency, in Hz.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFrequencySet` method instead.
@@ -1398,7 +1406,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def frequencyGet(self, channel_index: int) -> float:
-        """Get |AnalogOut| channel frequency, in Hz.
+        """Get the |AnalogOut| channel frequency, in Hz.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeFrequencyGet` method instead.
@@ -1420,7 +1428,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return hzFrequency
 
     def amplitudeInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get |AnalogOut| channel amplitude range info.
+        """Get the |AnalogOut| channel amplitude range info.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeAmplitudeInfo` method instead.
@@ -1444,7 +1452,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (amplitude_min, amplitude_max)
 
     def amplitudeSet(self, channel_index: int, amplitude: float) -> None:
-        """Set |AnalogOut| channel amplitude.
+        """Set the |AnalogOut| channel amplitude.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeAmplitudeSet` method instead.
@@ -1461,7 +1469,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def amplitudeGet(self, channel_index: int) -> float:
-        """Get |AnalogOut| channel amplitude.
+        """Get the |AnalogOut| channel amplitude.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeAmplitudeGet` method instead.
@@ -1483,7 +1491,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return amplitude
 
     def offsetInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get |AnalogOut| channel offset range info, in Volts.
+        """Get the |AnalogOut| channel offset range info, in Volts.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeOffsetInfo` method instead.
@@ -1507,7 +1515,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (offset_min, offset_max)
 
     def offsetSet(self, channel_index: int, offset: float) -> None:
-        """Set |AnalogOut| channel offset, in Volts.
+        """Set the |AnalogOut| channel offset, in Volts.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeOffsetSet` method instead.
@@ -1524,7 +1532,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def offsetGet(self, channel_index: int) -> float:
-        """Get |AnalogOut| channel offset, in Volts.
+        """Get the |AnalogOut| channel offset, in Volts.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeOffsetGet` method instead.
@@ -1546,7 +1554,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return offset
 
     def symmetryInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get |AnalogOut| channel symmetry setting range.
+        """Get the |AnalogOut| channel symmetry setting range.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeSymmetryInfo` method instead.
@@ -1570,7 +1578,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (symmetry_min, symmetry_max)
 
     def symmetrySet(self, channel_index: int, symmetry: float) -> None:
-        """Set |AnalogOut| channel symmetry setting.
+        """Set the |AnalogOut| channel symmetry setting.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeSymmetrySet` method instead.
@@ -1587,7 +1595,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def symmetryGet(self, channel_index: int) -> float:
-        """Get |AnalogOut| channel symmetry setting.
+        """Get the |AnalogOut| channel symmetry setting.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeSymmetryGet` method instead.
@@ -1609,7 +1617,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return symmetry
 
     def phaseInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get |AnalogOut| channel phase range, in degrees.
+        """Get the |AnalogOut| channel phase range, in degrees.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodePhaseInfo` method instead.
@@ -1633,7 +1641,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (phase_min, phase_max)
 
     def phaseSet(self, channel_index: int, phase: float) -> None:
-        """Set |AnalogOut| channel phase, in degrees.
+        """Set the |AnalogOut| channel phase, in degrees.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodePhaseSet` method instead.
@@ -1650,7 +1658,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def phaseGet(self, channel_index: int) -> float:
-        """Get |AnalogOut| channel phase, in degrees.
+        """Get the |AnalogOut| channel phase, in degrees.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodePhaseGet` method instead.
@@ -1678,7 +1686,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def dataInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get data buffer info.
+        """Get the |AnalogOut| channel data buffer info.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeDataInfo` method instead.
@@ -1702,7 +1710,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (num_samples_min, num_samples_max)
 
     def dataSet(self, channel_index: int, data: np.ndarray) -> None:
-        """Set carrier data.
+        """Set the |AnalogOut| channel data.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodeDataSet` method instead.
@@ -1726,7 +1734,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def playStatus(self, channel_index: int) -> Tuple[int, int, int]:
-        """Get play status.
+        """Get the |AnalogOut| channel playback status, in samples.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodePlayStatus` method instead.
@@ -1735,7 +1743,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[int, int, int]: The play status.
+            Tuple[int, int, int]: The playback status.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1757,14 +1765,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         return (data_free, data_lost, data_corrupted)
 
     def playData(self, channel_index: int, data: np.ndarray) -> None:
-        """Play data.
+        """Provide the |AnalogOut| channel playback data.
 
         Warning:
             This method is obsolete. Use the :py:meth:`nodePlayData` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            data (np.ndarray): The data.
+            data (np.ndarray): The playback data.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
