@@ -85,7 +85,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def statusTime(self) -> Tuple[int, int, int]:
-        """Get status timestamp.
+        """Get the |DigitalIn| status timestamp.
 
         Returns:
             Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
@@ -114,7 +114,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (sec_utc, tick, ticks_per_second)
 
     def statusAutoTriggered(self) -> bool:
-        """Verify if the acquisition is auto triggered.
+        """Verify if the |DigitalIn| acquisition is auto triggered.
 
         Returns:
             bool: True if the current acquisition is auto-triggered, False otherwise.
@@ -130,7 +130,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return auto_triggered
 
     def statusSamplesLeft(self) -> int:
-        """Retrieve the number of samples left in the acquisition.
+        """Retrieve the number of samples left in the |DigitalIn| acquisition.
 
         Returns:
             int: In case a finite-duration acquisition is active, the number of samples
@@ -147,7 +147,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samplesLeft
 
     def statusSamplesValid(self) -> int:
-        """Retrieve the number of valid/acquired data samples.
+        """Retrieve the number of valid/acquired |DigitalIn| data samples.
 
         Returns:
             int: The number of valid samples.
@@ -163,7 +163,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samples_valid
 
     def statusIndexWrite(self) -> int:
-        """Retrieve the buffer write pointer.
+        """Retrieve the |DigitalIn| buffer write pointer.
 
         This is needed in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.ScanScreen`
         acquisition mode to display the scan bar.
@@ -182,7 +182,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return index_write
 
     def statusRecord(self) -> Tuple[int, int, int]:
-        """Get recording status.
+        """Get the |DigitalIn| recording status.
 
         Returns:
             Tuple[int, int, int]: A three-element tuple containing the counts for
@@ -251,7 +251,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samples
 
     def statusNoise2(self, first_sample: int, count_bytes: int) -> np.ndarray:
-        """Get noise data.
+        """Get the noise data from the |DigitalIn| instrument.
 
         Todo:
             Figure out data format.
@@ -276,7 +276,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def internalClockInfo(self) -> float:
-        """Get internal clock frequency, in Hz.
+        """Get the |DigitalIn| internal clock frequency, in Hz.
 
         Returns:
             The internal clock frequency, in Hz.
@@ -292,7 +292,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return hzFreq
 
     def clockSourceInfo(self) -> List[DwfDigitalInClockSource]:
-        """Get digital-in clock source info.
+        """Get the valid |DigitalIn| clock sources.
 
         Returns:
             List[DwfDigitalInClockSource]: A list of valid clock sources.
@@ -310,7 +310,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return clock_source_list
 
     def clockSourceSet(self, clock_source: DwfDigitalInClockSource) -> None:
-        """Set clock source.
+        """Set the |DigitalIn| instrument clock source.
 
         Parameters:
             clock_source (DwfDigitalInClockSource): The clock source to be selected.
@@ -323,7 +323,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def clockSourceGet(self) -> DwfDigitalInClockSource:
-        """Get clock source.
+        """Get the |DigitalIn| instrument clock source.
 
         Returns:
             DwfDigitalInClockSource: The currently configured |DigitalIn| clock source.
@@ -339,7 +339,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return clock_source
 
     def dividerInfo(self) -> int:
-        """Get divider info.
+        """Get the |DigitalIn| instrument maximum divider value.
 
         Returns:
             int: The maximum valid divider value that can be configured.
@@ -355,7 +355,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return divider_max
 
     def dividerSet(self, divider: int) -> None:
-        """Set divider value.
+        """Set the |DigitalIn| instrument divider value.
 
         Parameters:
             divider: The divider value to be configured.
@@ -368,7 +368,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def dividerGet(self) -> int:
-        """Get divider value.
+        """Get the current |DigitalIn| instrument divider value.
 
         Returns:
             int: The currently configured divider value.
@@ -390,7 +390,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
-        """Get digital-in acquisition mode info.
+        """Get the valid |DigitalIn| acquisition modes.
 
         Returns:
             List[DwfAcquisitionMode]: A list of valid acquisition modes.
@@ -408,7 +408,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return acquisition_mode_list
 
     def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
-        """Set acquisition mode.
+        """Set the |DigitalIn| acquisition mode.
 
         Parameters:
             acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
@@ -421,7 +421,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def acquisitionModeGet(self) -> DwfAcquisitionMode:
-        """Get acquisition mode.
+        """Get the |DigitalIn| acquisition mode.
 
         Returns:
             DwfAcquisitionMode: The currently active acquisition mode.
@@ -437,7 +437,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return acquisition_mode
 
     def bitsInfo(self) -> int:
-        """Get bits info.
+        """Get the number of |DigitalIn| bits.
 
         Returns:
             The number of digital input bits available.
@@ -453,7 +453,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return num_bits
 
     def sampleFormatSet(self, num_bits: int) -> None:
-        """Set sample format.
+        """Set the |DigitalIn| sample format (number of bits).
 
         Parameters:
             num_bits (int): The number of bits per sample (8, 16, or 32).
@@ -466,7 +466,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sampleFormatGet(self) -> int:
-        """Get sample format.
+        """Get the |DigitalIn| sample format (number of bits).
 
         Returns:
             int: The currently configured number of bits per sample (8, 16, or 32).
@@ -482,7 +482,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return num_bits
 
     def inputOrderSet(self, dio_first: bool) -> None:
-        """Configure the order of values stored in the sampling array.
+        """Configure the |DigitalIn| order of values stored in the sampling array.
 
         If dio_first is True, DIO 24..39 are placed at the beginning of the array followed by DIN 0..23.
         If dio_first is False, DIN 0..23 are placed at the beginning followed by DIO 24..31.
@@ -500,7 +500,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def bufferSizeInfo(self) -> int:
-        """Get buffer size info.
+        """Get the |DigitalIn| instrument maximum buffer size.
 
         Returns:
             int: The maximum valid buffer size.
@@ -516,7 +516,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return buffer_size_max
 
     def bufferSizeSet(self, buffer_size: int) -> None:
-        """Set buffer size.
+        """Set the |DigitalIn| instrument buffer size.
 
         Parameters:
             buffer_size (int): The buffer size to be configured.
@@ -529,7 +529,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def bufferSizeGet(self) -> int:
-        """Get buffer size.
+        """Get the |DigitalIn| instrument buffer size.
 
         Returns:
             int: The currently configured buffer size.
@@ -545,7 +545,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return buffer_size
 
     def sampleModeInfo(self) -> List[DwfDigitalInSampleMode]:
-        """Get digital-in sample mode info.
+        """Get the valid |DigitalIn| instrument sample modes.
 
         Returns:
             List[DwfDigitalInSampleMode]: A list of valid sample modes.
@@ -563,7 +563,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return sample_mode_list
 
     def sampleModeSet(self, sample_mode: DwfDigitalInSampleMode) -> None:
-        """Set sample mode.
+        """Set the |DigitalIn| instrument sample mode.
 
         Parameters:
             sample_mode (DwfDigitalInSampleMode): The sample mode to be configured.
@@ -576,7 +576,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sampleModeGet(self) -> DwfDigitalInSampleMode:
-        """Get sample mode.
+        """Get the |DigitalIn|  instrument sample mode.
 
         Returns:
             DwfDigitalInSampleMode: The currently configured sample mode.
@@ -592,14 +592,14 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return sample_mode
 
     def sampleSensibleSet(self, compression_bits: int) -> None:
-        """Set sample sensible setting.
-
-        Parameters:
-            compression_bits (int): (unknown)
+        """Set the |DigitalIn| instrument *sample sensible* setting.
 
         Todo:
             Figure out what this setting does.
 
+        Parameters:
+            compression_bits (int): (unknown)
+
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
@@ -608,14 +608,14 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sampleSensibleGet(self) -> int:
-        """Get sample sensible setting.
-
-        Returns:
-            int: The sample sensible setting.
+        """Get the |DigitalIn| instrument *sample sensible* setting.
 
         Todo:
             Figure out what this setting does.
 
+        Returns:
+            int: The sample sensible setting.
+
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
@@ -627,7 +627,9 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return compression_bits
 
     def triggerPrefillSet(self, samples_before_trigger: int) -> None:
-        """Set trigger prefill, in samples.
+        """Set the |DigitalIn| instrument trigger prefill setting, in samples.
+
+        This setting is only used in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` mode.
 
         Parameters:
             samples_before_trigger (int): The prefill count, in samples.
@@ -640,7 +642,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerPrefillGet(self) -> int:
-        """Get trigger prefill, in samples.
+        """Get the |DigitalIn| instrument trigger prefill setting, in samples.
 
         Returns:
             int: The trigger prefill count, in samples.
@@ -662,13 +664,13 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get trigger source info.
+        """Get the valid |DigitalIn| instrument trigger sources.
 
         Note:
             This method is obsolete. Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
 
         Returns:
-            List[DwfTriggerSource]: A list of valid trigger source options.
+            List[DwfTriggerSource]: A list of valid trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -683,7 +685,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return trigger_source_list
 
     def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
-        """Set |DigitalIn| trigger source.
+        """Set |DigitalIn| instrument trigger source.
 
         Parameters:
             trigger_source (DwfTriggerSource): The trigger source to be configured.
@@ -696,7 +698,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get |DigitalIn| trigger source.
+        """Get |DigitalIn| instrument trigger source.
 
         Returns:
             DwfTriggerSource: The currently configured |DigitalIn| trigger source.
@@ -712,7 +714,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerPositionInfo(self) -> int:
-        """Get trigger position info.
+        """Get |DigitalIn| trigger position info.
 
         Returns:
             int: The maximum number of samples after the trigger.
@@ -730,7 +732,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return max_samples_after_trigger
 
     def triggerPositionSet(self, samples_after_trigger: int) -> None:
-        """Set trigger desired position.
+        """Set |DigitalIn| instrument desired trigger position.
 
         Parameters:
             samples_after_trigger (int): The number of samples after the trigger.
@@ -743,7 +745,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerPositionGet(self) -> int:
-        """Get trigger desired position.
+        """Get |DigitalIn| instrument trigger position.
 
         Returns:
             int: The currently configured number of samples after the trigger.
@@ -759,7 +761,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samples_after_trigger
 
     def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
-        """Get trigger auto-timeout range, in seconds.
+        """Get |DigitalIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
             Tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
@@ -787,7 +789,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (trigger_auto_timeout_min, trigger_auto_timeout_max, trigger_auto_timeout_num_steps)
 
     def triggerAutoTimeoutSet(self, auto_timeout: float) -> None:
-        """Set trigger auto-timeout value, in seconds.
+        """Set |DigitalIn| instrument trigger auto-timeout value, in seconds.
 
         Parameters:
             auto_timeout (float): The auto-timeout value to be configured, in seconds.
@@ -800,7 +802,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerAutoTimeoutGet(self) -> float:
-        """Get trigger auto-timeout value, in seconds.
+        """Get |DigitalIn| instrument trigger auto-timeout value, in seconds.
 
         Returns:
             float: The currently configured trigger auto-timeout value, in seconds.
@@ -822,7 +824,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
-        """Set trigger slope.
+        """Set |DigitalIn| trigger detector slope.
 
         Parameters:
             trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
@@ -835,7 +837,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self) -> DwfTriggerSlope:
-        """Get trigger slope.
+        """Get |DigitalIn| trigger detector slope.
 
         Returns:
             DwfTriggerSlope: The currently configured trigger slope.
@@ -851,7 +853,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return trigger_slope
 
     def triggerInfo(self) -> Tuple[int, int, int, int]:
-        """Get trigger info.
+        """Get |DigitalIn| detector trigger info.
 
         Returns:
             Tuple[int, int, int, int]: (to be documented)
@@ -878,7 +880,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (fsLevelLow, fsLevelHigh, fsEdgeRise, fsEdgeFall)
 
     def triggerSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
-        """Set trigger settings.
+        """Set |DigitalIn| trigger detector settings.
 
         Parameters:
             level_low (int): Bit-field; channels that trigger when level is low.
@@ -899,7 +901,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerGet(self) -> Tuple[int, int, int, int]:
-        """Get trigger.
+        """Get |DigitalIn| trigger detector settings.
 
         Returns:
             Tuple[int, int, int, int]: bitfields for level_low, level_high, edge_rise, edge_fall sensitivity.
@@ -926,7 +928,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (level_low, level_high, edge_rise, edge_fall)
 
     def triggerResetSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
-        """Configure trigger reset settings.
+        """Configure |DigitalIn| trigger detector reset settings.
 
         Parameters:
             level_low (int):  (to be documented)
@@ -947,7 +949,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerCountSet(self, count: int, restart: int) -> None:
-        """Set trigger count.
+        """Set |DigitalIn| trigger detector count.
 
         Parameters:
             count (int): (to be documented)
@@ -961,7 +963,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerLengthSet(self, trigger_length_min: float, trigger_length_max: float, index_sync: int) -> None:
-        """Set trigger length.
+        """Set |DigitalIn| trigger detector length.
 
         Parameters:
             trigger_length_min (int): (to be documented)
@@ -976,7 +978,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerMatchSet(self, pin: int, mask: int, value: int, bit_stuffing: int) -> None:
-        """Set trigger match.
+        """Set |DigitalIn| trigger detector match.
 
         Parameters:
             pin (int): (to be documented)
