@@ -31,7 +31,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def reset(self) -> None:
-        """Reset the digital-out instrument.
+        """Reset the |DigitalOut| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *reset* operation.
@@ -41,7 +41,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def configure(self, start: bool) -> None:
-        """Start or stop the digital-out instrument.
+        """Start or stop the |DigitalOut| instrument.
 
         Parameters:
             start (int): Whether to start/stop the instrument.
@@ -78,7 +78,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def count(self) -> int:
-        """Get digital-out channel count.
+        """Get the |DigitalOut| instrument channel (digital pin) count.
 
         Returns:
             int: The number of digital output channels.
@@ -100,11 +100,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def waitInfo(self) -> Tuple[float, float]:
-        """Get minimal and maximal wait-time preceding digital-out pulse-sequence runs, in seconds.
+        """Get the |DigitalOut| instrument range for the |Wait:link| state duration, in seconds.
 
         Returns:
-            Tuple[float, float]: A tuple containing the minimal and maximal configurable wait durations that should
-            precede a pulse-train output, expressed in seconds.
+            Tuple[float, float]: A tuple containing the minimal and maximal configurable |Wait:link| state duration,
+            in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -119,10 +119,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (wait_duration_min, wait_duration_max)
 
     def waitSet(self, wait_duration: float) -> None:
-        """Set wait duration before digital-out pulse-sequence runs, in seconds.
+        """Set the |DigitalOut| instrument |Wait:link| state duration, in seconds.
 
         Parameters:
-            wait_duration (float): Digital-out wait duration, in seconds.
+            wait_duration (float): Digital-out |Wait:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -132,10 +132,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def waitGet(self) -> float:
-        """Get wait duration before digital-out pulse-sequence runs, in seconds.
+        """Get |DigitalOut| instrument |Wait:link| state duration, in seconds.
 
         Returns:
-            float: Digital-out wait duration, in seconds.
+            float: The |Wait:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -148,10 +148,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return wait_duration
 
     def runInfo(self) -> Tuple[float, float]:
-        """Get minimal and maximal duration for a single digital-out pulse sequence run, in seconds.
+        """Get the |DigitalOut| instrument range for the |Running:link| state duration, in seconds.
 
         Returns:
-            Tuple[float, float]: A tuple containing the minimal and maximal digital-out run duration, in seconds.
+            Tuple[float, float]: A tuple containing the minimal and maximal |Running:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -166,13 +166,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (run_duration_min, run_duration_max)
 
     def runSet(self, run_duration: float) -> None:
-        """Set duration for a single digital-out pulse sequence run, in seconds.
+        """Set the |DigitalOut| instrument |Running:link| state duration, in seconds.
 
         Parameters:
-            run_duration: The run duration, in seconds.
-
-        Parameters:
-            run_duration (float): Digital-out runtime, in seconds.
+            run_duration: The |Running:link| state duration, in seconds.
 
                 The value 0 is special; it means *forever*.
 
@@ -184,10 +181,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def runGet(self) -> float:
-        """Get duration for a single digital-out pulse sequence run, in seconds.
+        """Get the |DigitalOut| instrument |Running:link| state duration, in seconds.
 
         Returns:
-            float: digital-out run-time, in seconds.
+            float: The |Running:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -200,7 +197,8 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return run_duration
 
     def runStatus(self) -> int:
-        """Get run-time for the currently active digital-out pulse sequence run.
+        """Get the |DigitalOut| instrument |Running:link| state duration time left,
+        in clock cycles.
 
         This value is internally expressed as an integer with 48-bit resolution,
         and is measured in integer clock cycles. The C API returns it as a
@@ -227,7 +225,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return run_status
 
     def repeatTriggerSet(self, repeat_trigger_flag: bool) -> None:
-        """Specify if each pulse sequence run should wait for its own trigger.
+        """Specify if each |DigitalOut| pulse sequence run should wait for its own trigger.
 
         Parameters:
             repeat_trigger_flag (bool): If True, not only the first, both also every successive run of the
@@ -241,7 +239,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def repeatTriggerGet(self) -> bool:
-        """Get if each pulse sequence run should wait for its own trigger.
+        """Get if each |DigitalOut| pulse sequence run should wait for its own trigger.
 
         Returns:
             bool: If True, not only the first, both also every successive run of the pulse output sequence
@@ -255,7 +253,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return repeat_trigger_flag
 
     def repeatInfo(self) -> Tuple[int, int]:
-        """Get minimal and maximal repeat count for digital-out pulse-sequence runs.
+        """Get the |DigitalOut| minimal and maximal repeat count for pulse-sequence runs.
 
         Returns:
             Tuple[int, int]: A tuple containing the minimal and maximal repeat count for
@@ -274,7 +272,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (repeat_min, repeat_max)
 
     def repeatSet(self, repeat: int) -> None:
-        """Set repeat count for digital-out pulse-sequence runs.
+        """Set the |DigitalOut| repeat count for pulse-sequence runs.
 
         Parameters:
             repeat (int): Repeat count.
@@ -288,7 +286,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def repeatGet(self) -> int:
-        """Set repeat count for digital-out pulse-sequence runs.
+        """Set the |DigitalOut| repeat count for pulse-sequence runs.
 
         Returns:
             int: Repeat count.
@@ -305,7 +303,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return repeat
 
     def repeatStatus(self) -> int:
-        """Get repeat status for the currently active digital-out train of pulse-sequence runs.
+        """Get the |DigitalOut| count of repeats remaining for the currently active output sequence.
 
         This number counts down as a digital output sequence is active.
 
@@ -329,13 +327,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get digital-out trigger source info.
+        """Get the valid |DigitalOut| trigger sources.
 
         Note:
             This method is obsolete. Use the generic DeviceControl.triggerInfo() method instead.
 
         Returns:
-            List[DwfTriggerSource]: A list of possible choices for the trigger source.
+            List[DwfTriggerSource]: A list of valid the trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -350,7 +348,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return trigger_source_list
 
     def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
-        """Set the trigger source.
+        """Set the |DigitalOut| trigger source.
 
         Parameters:
             trigger_source (DwfTriggerSource): The trigger source to be configured.
@@ -363,7 +361,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the currently active trigger source.
+        """Get the currently configured |DigitalOut| trigger source.
 
         Returns:
             DwfTriggerSource: The currently configured trigger source.
@@ -379,7 +377,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return trigger_source
 
     def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
-        """Set the slope for the digital-out trigger.
+        """Set the |DigitalOut| trigger slope.
 
         Parameters:
             trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
@@ -392,7 +390,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSlopeGet(self) -> DwfTriggerSlope:
-        """Get the slope for the digital-out trigger.
+        """Get the currently configured |DigitalOut| trigger slope.
 
         Returns:
             DwfTriggerSlope: The currently configured trigger slope.
@@ -414,7 +412,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def enableSet(self, channel_index: int, enable_flag: bool) -> None:
-        """Enable or disable a digital-out channel.
+        """Enable or disable a |DigitalOut| channel (pin).
 
         Parameters:
             channel_index (int): The digital pin to enable or disable.
@@ -428,7 +426,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def enableGet(self, channel_index: int) -> bool:
-        """Check if a specific digital pin is enabled for output.
+        """Check if a specific |DigitalOut| channel (pin) is enabled for output.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -447,7 +445,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return enable_flag
 
     def outputInfo(self, channel_index: int) -> List[DwfDigitalOutOutput]:
-        """Get output info.
+        """Get valid |DigitalOut| output choices (e.g. Push/Pull, tristate).
 
         Returns:
             List[DwfDigitalOutOutput]: A list of valid output settings.
@@ -464,7 +462,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return output_list
 
     def outputSet(self, channel_index: int, output_value: DwfDigitalOutOutput) -> None:
-        """Set output.
+        """Set |DigitalOut| output choice (e.g. Push/Pull, tristate).
 
         Parameters:
             channel_index (int): The digital pin.
@@ -478,7 +476,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def outputGet(self, channel_index: int) -> DwfDigitalOutOutput:
-        """Get output.
+        """Get currently active |DigitalOut| output  (e.g. Push/Pull, tristate).
 
         Parameters:
             channel_index (int): The digital pin.
@@ -497,7 +495,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return output_value
 
     def typeInfo(self, channel_index: int) -> List[DwfDigitalOutType]:
-        """Get a list of possible output signal type values.
+        """Get valid |DigitalOut| output signal types.
 
         Returns:
             List[DwfDigitalOutType]: A list of valid digital output types.
@@ -514,7 +512,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return type_list
 
     def typeSet(self, channel_index: int, output_type: DwfDigitalOutType) -> None:
-        """Set output signal type.
+        """Set the |DigitalOut| output signal type.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -528,7 +526,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def typeGet(self, channel_index: int) -> DwfDigitalOutType:
-        """Get currently configured output signal type.
+        """Get the currently configured |DigitalOut| output signal type.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -547,10 +545,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return output_type
 
     def idleInfo(self, channel_index: int) -> List[DwfDigitalOutIdle]:
-        """Get a list of valid idle behavior setting values.
+        """Get valid |DigitalOut| idle output values.
 
         Returns:
-            List[DwfDigitalOutIdle]: A list of valid digital idle options.
+            List[DwfDigitalOutIdle]: A list of valid idle output values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -564,11 +562,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return idle_list
 
     def idleSet(self, channel_index: int, idle_mode: DwfDigitalOutIdle) -> None:
-        """Set idle behavior setting.
+        """Set the |DigitalOut| idle output value.
 
         Parameters:
             channel_index (int): The digital pin.
-            idle_mode (DwfDigitalOutIdle): The digital idle setting.
+            idle_mode (DwfDigitalOutIdle): The idle output value setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -578,13 +576,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def idleGet(self, channel_index: int) -> DwfDigitalOutIdle:
-        """Get currently active idle behavior setting.
+        """Get the currently active idle output value.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            DwfDigitalOutIdle: The current digital idle setting.
+            DwfDigitalOutIdle: The current idle output value setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -603,7 +601,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def internalClockInfo(self) -> float:
-        """Get digital-out clock frequency.
+        """Get the |DigitalOut| instrument clock frequency.
 
         Returns:
             float: The digital-out clock frequency, in Hz.
@@ -619,7 +617,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return internal_clock_frequency
 
     def dividerInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get divider value range.
+        """Get the |DigitalOut| divider value range.
 
         Returns:
             Tuple[int, int]: The range of valid divider settings.
@@ -641,7 +639,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (divider_min, divider_max)
 
     def dividerSet(self, channel_index: int, divider: int) -> None:
-        """Set divider value.
+        """Set the |DigitalOut| divider value.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -655,7 +653,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def dividerGet(self, channel_index: int) -> int:
-        """Get currently configured divider value.
+        """Get the currently configured |DigitalOut| divider value.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -674,7 +672,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return divider
 
     def dividerInitSet(self, channel_index: int, divider_init: int) -> None:
-        """Set initial divider value.
+        """Set the |DigitalOut| initial divider value.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -688,7 +686,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def dividerInitGet(self, channel_index: int) -> int:
-        """Get currently configured initial divider value.
+        """Get the currently configured |DigitalOut| initial divider value.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -707,7 +705,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return divider_init
 
     def counterInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get counter value range.
+        """Get the |DigitalOut| counter value range.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -732,7 +730,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (counter_min, counter_max)
 
     def counterSet(self, channel_index: int, low_count: int, high_count: int) -> None:
-        """Set counter durations for both the low and high signal output levels.
+        """Set the |DigitalOut| counter durations for both the low and high signal output levels.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -747,7 +745,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def counterGet(self, channel_index: int) -> Tuple[int, int]:
-        """Get counter durations for both the low and high signal output levels.
+        """Get the |DigitalOut| counter durations for both the low and high signal output levels.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -768,7 +766,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return (low_count, high_count)
 
     def counterInitSet(self, channel_index: int, high: bool, counter_init: int) -> None:
-        """Set initial signal value and initial counter value.
+        """Set the |DigitalOut| initial signal value and initial counter value.
 
         Parameters:
             channel_index (int): The digital pin.
@@ -786,14 +784,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def counterInitGet(self, channel_index: int) -> Tuple[bool, int]:
-        """Get initial signal value and initial counter value.
+        """Get the |DigitalOut| initial signal value and initial counter value.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
             Tuple [bool, int]: Whether to start High (True) or Low (False),
-            and The initial counter setting.
+            and the initial counter setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -837,12 +835,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         return max_data_bits
 
     def dataSet(self, channel_index: int, bits: str, tristate: bool = False) -> None:
-        """Set digital-out arbitrary channel data.
+        """Set the |DigitalOut| arbitrary output data.
 
         Parameters:
-            channel_index (int): the channel for which to obtain the data bits count.
+            channel_index (int): the channel for which to set the output data.
             bits (str): The bits, as a string.
             tristate (bool): Whether to interpret the string as a tristate signal.
+
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
@@ -866,7 +865,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def playDataSet(self, rg_bits: int, bits_per_sample: int, count_of_samples: int) -> None:
-        """Set playback data.
+        """Set the |DigitalOut| playback data.
 
         Parameters:
             rg_bits (int): (to be documented)
@@ -885,7 +884,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def playRateSet(self, playback_rate: float) -> None:
-        """Set |DigitalOut| playback rate, in Hz.
+        """Set the |DigitalOut| playback rate, in Hz.
 
         Parameters:
             playback_rate (float): The playback rate, in Hz.
