@@ -64,10 +64,10 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
                 The data bit to configure:
 
-                * 0: DQ0 / MOSI
-                * 1: DQ1 / MISO
-                * 2: DQ2
-                * 3: DQ3
+                * 0 — DQ0 / MOSI
+                * 1 — DQ1 / MISO
+                * 2 — DQ2
+                * 3 — DQ3
 
             channel_index (int):
                 Digital channel (pin) for this data bit.
@@ -87,10 +87,10 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
                 The data bit to configure:
 
-                * 0: DQ0 / MOSI
-                * 1: DQ1 / MISO
-                * 2: DQ2
-                * 3: DQ3
+                * 0 — DQ0 / MOSI
+                * 1 — DQ1 / MISO
+                * 2 — DQ2
+                * 3 — DQ3
 
             idle_mode (DwfDigitalOutIdle):
                 Idle behavior of this bit.
@@ -111,10 +111,10 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
                 The values for CPOL (polarity) and CPHA (phase) to use with the device under test:
 
-                * 0: CPOL = 0, CPHA = 0
-                * 1: CPOL = 0, CPHA = 1
-                * 2: CPOL = 1, CPHA = 0
-                * 3: CPOL = 1, CPHA = 1
+                * 0 — CPOL = 0, CPHA = 0
+                * 1 — CPOL = 0, CPHA = 1
+                * 2 — CPOL = 1, CPHA = 0
+                * 3 — CPOL = 1, CPHA = 1
 
                 Refer to the slave device's datasheet to select the correct value.
 
@@ -133,8 +133,8 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
                 Select the bit order of each word sent out:
 
-                * 1: MSB first, LSB last
-                * 0: LSB first, MSB last
+                * 1 — MSB first, LSB last
+                * 0 — LSB first, MSB last
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -155,9 +155,9 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
                 The Chip Select level to configure.
 
-                *  0: low
-                *  1: high
-                * -1: Z (high impedance)
+                *  0 — low
+                *  1 — high
+                * -1 — Z (high impedance)
 
                 The CS (chip select) is usually an active-low signal, from the
                 SPI bus master to a specific SPI device. before starting a bus
@@ -178,12 +178,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..8).
+                The number of bits per data-word (1…8).
             tx (List[int]):
                 The data-words to write.
 
@@ -222,12 +222,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..16).
+                The number of bits per data-word (1…16).
             tx (List[int]):
                 The data-words to write.
 
@@ -266,12 +266,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..32).
+                The number of bits per data-word (1…32).
             tx (List[int]):
                 The data-words to write.
 
@@ -311,12 +311,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..8).
+                The number of bits per data-word (1…8).
             number_of_words (int):
                 The number of data-words to read.
 
@@ -349,12 +349,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..16).
+                The number of bits per data-word (1…16).
             number_of_words (int):
                 The number of data-words to read.
 
@@ -387,12 +387,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..32).
+                The number of bits per data-word (1…32).
             number_of_words (int):
                 The number of data-words to read.
 
@@ -425,13 +425,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits of the data-word (1..32).
+                The number of bits of the data-word (1…32).
 
         Returns:
             int: The data-word received.
@@ -451,12 +450,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..32).
+                The number of bits per data-word (1…32).
             tx (List[int]):
                 The data-words to write.
 
@@ -485,12 +484,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..16).
+                The number of bits per data-word (1…16).
             tx (List[int]):
                 The data-words to write.
 
@@ -519,12 +518,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits per data-word (1..32).
+                The number of bits per data-word (1…32).
             tx (List[int]):
                 The data-words to write.
 
@@ -552,12 +551,12 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         Parameters:
             transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
+                * 0 — SISO
+                * 1 — MOSI/MISO
+                * 2 — dual
+                * 4 — quad
             bits_per_word (int):
-                The number of bits of the data-word (1..32).
+                The number of bits of the data-word (1…32).
             tx (int):
                 The data-word to write.
 
