@@ -27,7 +27,7 @@ class DwfErrorCode(_FixReprMethod, enum.Enum):
     This type is used by the |DwfLibrary.getLastError:link| method to report the error condition of the most
     recent C API call.
 
-    In |pydwf|, it is only seen as the contents of the :py:attr:`~pydwf.core.auxiliary.exceptions.DwfLibraryError.code`
+    In |pydwf|, it is only used as the type of the :py:attr:`~pydwf.core.auxiliary.exceptions.DwfLibraryError.code`
     field of |DwfLibraryError:link| instances.
 
     In the C API, this type is called 'DWFERC', and it is represented as an *int*.
@@ -92,25 +92,11 @@ class DwfEnumFilter(_FixReprMethod, enum.Enum):
 
 @enum.unique
 class DwfEnumConfigInfo(_FixReprMethod, enum.Enum):
-    """Enumeration type for configuration parameter type constants.
+    """Enumeration type for device configuration parameter type constants.
 
-    This type lists the device parameters that can vary between different configurations
+    This type lists the device parameters that can vary between different |device configurations:link|
     of the same device.
 
-    For some Digilent Waveforms devices, multiple firmware configurations are available that make
-    different tradeoffs for certain hard-coded parameters.
-
-    For example, one configuration may support a lot of buffering memory for the |AnalogIn| instrument,
-    while another configuration may support a lot of buffering memory for the |DigitalOut| instrument.
-
-    The user can specify which device configuration to use when opening the device; the configuration
-    is then fixed during use, until the device is closed.
-
-    For many use cases, the default configuration that provides a balanced tradeoff works fine. User
-    programs that need more control can use the |DeviceEnum.configInfo:link| method during device
-    enumeration to inspect the different configurations available, and use the information obtained
-    to pick the best configuration.
-
     In the C API, this type is represented as an *int*.
     """
 
@@ -243,8 +229,8 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
 
     Possible values:
 
-    * 0: Disable USB power.
-    * 1: Keep USB power enabled.
+    * 0 — Disable USB power.
+    * 1 — Keep USB power enabled.
 
     This setting is implemented on the Analog Discovery 2.
     """
@@ -266,9 +252,9 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
 
     Possible values:
 
-    * 0: On close, continue.
-    * 1: On close, stop the device.
-    * 2: On close, shut down the device.
+    * 0 — On close, continue.
+    * 1 — On close, stop the device.
+    * 2 — On close, shut down the device.
     """
 
     AudioOut = 5
@@ -276,8 +262,8 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
 
     Possible values:
 
-    * 0: Disable audio output.
-    * 1: Enable audio output.
+    * 0 — Disable audio output.
+    * 1 — Enable audio output.
 
     This setting is implemented on the Analog Discovery and the Analog Discovery 2.
     """
@@ -295,8 +281,8 @@ class DwfDeviceParameter(_FixReprMethod, enum.Enum):
 
     Possible values:
 
-    * 0: Disable analog output.
-    * 1: Enable analog output.
+    * 0 — Disable analog output.
+    * 1 — Enable analog output.
     """
 
     Frequency = 8
@@ -316,7 +302,7 @@ class DwfState(_FixReprMethod, enum.Enum):
     The following instrument APIs are controlled by a state machine:
 
     * |AnalogIn|
-    * |AnalogOut|
+    * |AnalogOut| — *independent state machine for each channel*
     * |DigitalIn|
     * |DigitalOut|
     * |AnalogImpedance|
@@ -389,16 +375,16 @@ class DwfTriggerSource(_FixReprMethod, enum.Enum):
     """DigitalOut instrument start."""
 
     AnalogOut1 = 7
-    """AnalogOut instrument channel 1 start."""
+    """|AnalogOut| instrument channel 1 start."""
 
     AnalogOut2 = 8
-    """AnalogOut instrument channel 2 start."""
+    """|AnalogOut| instrument channel 2 start."""
 
     AnalogOut3 = 9
-    """AnalogOut instrument channel 3 start."""
+    """|AnalogOut| instrument channel 3 start."""
 
     AnalogOut4 = 10
-    """AnalogOut instrument channel 4 start."""
+    """|AnalogOut| instrument channel 4 start."""
 
     External1 = 11
     """External trigger #1."""
