@@ -65,7 +65,7 @@ class DwfDevice:
         digitalI2c (DigitalI2c):
             Provides access to the I2C protocol functionality.
 
-    .. rubric:: |DwfDevice| methods
+    .. rubric:: |DwfDevice| properties and methods
     """
 
     # pylint: disable=too-many-instance-attributes
@@ -112,11 +112,12 @@ class DwfDevice:
 
     @property
     def dwf(self) -> 'DwfLibrary':
-        """Return the |DwfLibrary| instance.
+        """Return the |DwfLibrary| instance that was used to create (open) this |DwfDevice| instance.
 
-        This property is intended for internal |pydwf| use.
+        This is useful if we have a |DwfDevice|, but we need its |DwfLibrary|.
 
-        :meta private:
+        Returns:
+            DwfLibrary: The |DwfLibrary| that was used to create (open) this |DwfDevice| instance.
         """
         return self._dwf
 
@@ -157,10 +158,15 @@ class DwfDevice:
     def autoConfigureSet(self, auto_configure: int) -> None:
         """Enable or disable the auto-configuration setting of the device.
 
-        When this setting is enabled, the device is automatically configured every time an instrument parameter is set.
+        When this setting is enabled (the default), any change to an instrument setting is automatically
+        transmitted to the Digilent Waveforms hardware device, without the need for an explicit call to
+        the instrument's *configure()* method.
 
-        This adds latency to every *Set* method; just as much latency as calling the corresponding *configure*
-        method directly afterward.
+        This adds a small amount of latency to every *Set()* method; just as much latency as calling the
+        corresponding *configure()* method explicitly after the *Set()* method would add.
+
+        Auto-configuration is enabled by default, and there is little reason to turn it off unless the
+        user program wants to make frequent changes to many settings at once between measurements.
 
         With value 3, configuration will be applied dynamically, without stopping the instrument.
 
@@ -169,9 +175,9 @@ class DwfDevice:
 
                 Possible values for this option:
 
-                * 0: disable;
-                * 1: enable;
-                * 3: dynamic.
+                * 0 — disable
+                * 1 — enable
+                * 3 — dynamic
 
         Raises:
             DwfLibraryError: The value cannot be set.
@@ -184,13 +190,13 @@ class DwfDevice:
         """Return the auto-configuration setting of the device.
 
         Returns:
-            The current auto-configure setting.
+            int: The current auto-configure setting.
 
-            Possible values:
+            Possible values for this option:
 
-            * 0: disable;
-            * 1: enable;
-            * 3: dynamic.
+            * 0 — disable
+            * 1 — enable
+            * 3 — dynamic
 
         Raises:
             DwfLibraryError: The value cannot be retrieved.
@@ -204,9 +210,9 @@ class DwfDevice:
         return auto_configure
 
     def reset(self) -> None:
-        """Reset all device and instrument parameters to default values.
+        """Reset all device and instrument settings to default values.
 
-        The new settings are effectuated immediately if auto-configuration is enabled.
+        The new settings are applied immediately if auto-configuration is enabled.
 
         Raises:
             DwfLibraryError: The device cannot be reset.
@@ -229,7 +235,17 @@ class DwfDevice:
             raise self.dwf.exception()
 
     def triggerInfo(self) -> List[DwfTriggerSource]:
-        """Return the supported trigger source options for the global trigger bus.
+        """Return the available trigger source options for the global trigger bus.
+
+        Refer to the dedicated section on |triggering:link| for more information.
+
+        The four main instruments (|AnalogIn|, |AnalogOut|, |DigitalIn|, and |DigitalOut|) can be configured
+        to start their operation (data acquisition for the *In* instruments; signal generation for the *Out*
+        instruments) immediately after some event happens. This is called *triggering*.
+
+        Each of the instruments can be configured independently, to use any of the trigger sources available
+        inside the device. This method returns a list of all trigger sources that are available to each of the
+        instruments.
 
         Returns:
             List[DwfTriggerSource]: A list of available trigger sources.
@@ -249,8 +265,19 @@ class DwfDevice:
     def triggerSet(self, pin_index: int, trigger_source: DwfTriggerSource) -> None:
         """Configure the trigger I/O pin with a specific trigger source option.
 
+        Digilent Waveforms devices have dedicated digital I/O pins that can be used either
+        as trigger inputs or trigger outputs. Use this method to select which line of the
+        global triggering bus is driven on those pins, e.g. to trigger some external device
+        or to monitor the Digilent Waveforms device's internal trigger behavior.
+
+        Pass :py:attr:`DwfTriggerSource.None_ <pydwf.core.auxiliary.enum_typesDwfTriggerSource.None_>`
+        to disable trigger output on the pin. This is the default setting, and the appropriate value
+        to use when the intention is to have some external trigger signal drive the pin.
+
+        Refer to the dedicated section on |triggering:link| for more information.
+
         Parameters:
-            pin_index (int): The pin_index to configure.
+            pin_index (int): The trigger pin to configure.
             trigger_source (DwfTriggerSource): The trigger source to select.
 
         Raises:
@@ -263,7 +290,7 @@ class DwfDevice:
     def triggerGet(self, pin_index: int) -> DwfTriggerSource:
         """Return the selected trigger source for a trigger I/O pin.
 
-        The trigger source can be 'none', an internal instrument, or an external trigger.
+        Refer to the dedicated section on |triggering:link| for more information.
 
         Parameters:
             pin_index (int): The pin for which to obtain the selected trigger source.
@@ -282,7 +309,11 @@ class DwfDevice:
         return trigger_source
 
     def triggerPC(self) -> None:
-        """Generate one pulse on the PC trigger line.
+        """Generate a trigger pulse on the PC trigger line.
+
+        This pulse will trigger any instrument that is configured with trigger source
+        :py:attr:`DwfTriggerSource.PC <pydwf.core.auxiliary.enum_typesDwfTriggerSource.PC>`,
+        and currently armed (i.e., waiting for a trigger).
 
         Raises:
             DwfLibraryError: The PC trigger line cannot be pulsed.
@@ -309,7 +340,16 @@ class DwfDevice:
         return slope_list
 
     def paramSet(self, parameter: DwfDeviceParameter, value: int) -> None:
-        """Set a device parameter.
+        """Set a device parameter value.
+
+        Device parameters are settings of a specific |DwfDevice|.
+        Refer to the |device parameters:link| section for more information.
+
+        This method sets a device parameter value of a currently opened |DwfDevice|.
+
+        Warning:
+            The device parameter values are not checked to make sure they correspond to a valid
+            value for the specific device parameter.
 
         Parameters:
             parameter (DwfDeviceParameter): The device parameter to set.
@@ -323,7 +363,10 @@ class DwfDevice:
             raise self.dwf.exception()
 
     def paramGet(self, parameter: DwfDeviceParameter) -> int:
-        """Retrieve a device parameter.
+        """Retrieve a device parameter value.
+
+        Device parameters are settings of a specific |DwfDevice|.
+        Refer to the |device parameters:link| section for more information.
 
         Parameters:
             parameter (DwfDeviceParameter): The device parameter to retrieve.
