@@ -63,12 +63,15 @@ class DwfLibrary:
                 the shared library version; or a version mismatch was detected.
         """
 
-        if sys.platform.startswith("win"):
-            lib = ctypes.cdll.dwf
-        elif sys.platform.startswith("darwin"):
-            lib = ctypes.cdll.LoadLibrary("/Library/Frameworks/dwf.framework/dwf")
-        else:
-            lib = ctypes.cdll.LoadLibrary("libdwf.so")
+        try:
+            if sys.platform.startswith("win"):
+                lib = ctypes.cdll.dwf
+            elif sys.platform.startswith("darwin"):
+                lib = ctypes.cdll.LoadLibrary("/Library/Frameworks/dwf.framework/dwf")
+            else:
+                lib = ctypes.cdll.LoadLibrary("libdwf.so")
+        except OSError as exception:
+            raise PyDwfError("Unable to open DWF library using ctypes.") from exception
 
         if check_library_version:
             # Note that the 'FDwfGetVersion' function has not been type-annotated yet here.
@@ -221,8 +224,8 @@ class DwfLibrary:
         Device parameters are settings of a specific |DwfDevice|.
         Refer to the |device parameters:link| section for more information.
 
-        This method sets device parameter values at the library level.
-        They are used as default device parameter values for devices that are opened subsequently.
+        This method sets a default device parameter value to be used for for devices that are
+        opened subsequently.
 
         Warning:
             The device parameter values are not checked to make sure they correspond to a valid
