@@ -7,17 +7,22 @@ if TYPE_CHECKING:
 
 
 class AbstractDwfLibrarySubApi:
-    """Abstract base class for the sub-API class members of a DwfLibrary."""
+    """Abstract base class for the sub-API class members of a |DwfLibrary|."""
 
     def __init__(self, dwf: 'DwfLibrary'):
         self._dwf = dwf
 
     @property
     def dwf(self):
-        """Return the library."""
+        """Return the library.
+        :meta private:
+        """
         return self._dwf
 
     @property
     def lib(self):
-        """Return the |ctypes:link| library."""
+        """Return the |ctypes| library.
+
+        :meta private:
+        """
         return self.dwf.lib
