@@ -31,13 +31,7 @@ def openDwfDevice(
 
        If the list that remains has a single device, this device will be used. If not, a |PyDwfError:link| is raised.
 
-    2. The next step is to select a *device configuration* for the selected device.
-
-       For some Digilent Waveforms devices, multiple firmware configurations are available that make
-       different tradeoffs for certain hard-coded parameters.
-
-       For example, one configuration may support a lot of buffering memory for the |AnalogIn| instrument,
-       while another configuration may support a lot of buffering memory for the |DigitalOut| instrument.
+    2. The next step is to select a |device configuration:link| for the selected device.
 
        For many use cases, the default configuration that provides a balanced tradeoff works fine.
        If no *score_func* is provided, this default configuration will be used.
